"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@checkup/core");
class OutdatedDependenciesTaskResult extends core_1.BaseTaskResult {
    process(data) {
        this.data = data;
        this.actionList = new core_1.ActionList([
            {
                name: 'percentage-major-outdated',
                threshold: 0.05,
                value: this.versionTypes.get('major').length / this.data.dependencies.length,
                get enabled() {
                    return this.value > this.threshold;
                },
                get message() {
                    return `${core_1.decimalToPercent(this.value)} of your dependencies are major versions behind, this should be at most ${core_1.decimalToPercent(this.threshold)}.`;
                },
            },
            {
                name: 'percentage-minor-outdated',
                threshold: 0.05,
                value: this.versionTypes.get('minor').length / this.data.dependencies.length,
                get enabled() {
                    return this.value > this.threshold;
                },
                get message() {
                    return `${core_1.decimalToPercent(this.value)} of your dependencies are minor versions behind, this should be at most ${core_1.decimalToPercent(this.threshold)}.`;
                },
            },
            {
                name: 'percentage-outdated',
                threshold: 0.2,
                value: this.outdatedDependencies.length / this.data.dependencies.length,
                get enabled() {
                    return this.value > this.threshold;
                },
                get message() {
                    return `${core_1.decimalToPercent(this.value)} of your dependencies are outdated, this should be at most ${core_1.decimalToPercent(this.threshold)}.`;
                },
            },
        ], this.config);
    }
    toConsole() {
        core_1.ui.section(this.meta.friendlyTaskName, () => {
            core_1.ui.sectionedBar([
                { title: 'major', count: this.versionTypes.get('major').length, color: 'red' },
                { title: 'minor', count: this.versionTypes.get('minor').length, color: 'orange' },
                { title: 'patch', count: this.versionTypes.get('patch').length, color: 'yellow' },
            ], this.data.dependencies.length);
        });
    }
    toJson() {
        return {
            meta: this.meta,
            result: {
                dependencies: this.outdatedDependencies,
            },
        };
    }
    get outdatedDependencies() {
        // if a dependency is up to date, the `bump` field will be null
        return this.data.dependencies.filter((dependency) => dependency.bump !== null);
    }
    get versionTypes() {
        var _a;
        let versionTypes = new Map([
            ['major', []],
            ['minor', []],
            ['patch', []],
        ]);
        for (let dependency of this.outdatedDependencies) {
            try {
                // for catching when dependency version is 'exotic', which means yarn cannot detect for you whether the package has become outdated
                (_a = versionTypes.get(dependency.bump)) === null || _a === void 0 ? void 0 : _a.push(dependency);
            }
            catch (_b) {
                // do nothing
            }
        }
        return versionTypes;
    }
}
exports.default = OutdatedDependenciesTaskResult;
//# sourceMappingURL=outdated-dependencies-task-result.js.map