"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@checkup/core");
const eslint_disable_task_result_1 = require("../results/eslint-disable-task-result");
const fs = require('fs');
const recast = require('recast');
const babel = require('@babel/parser');
const ESLINT_DISABLE_REGEX = /^eslint-disable(?:-next-line|-line)*/gi;
class EslintDisableTask extends core_1.BaseTask {
    constructor() {
        super(...arguments);
        this.meta = {
            taskName: 'eslint-disables',
            friendlyTaskName: 'Number of eslint-disable Usages',
            taskClassification: {
                category: 'linting',
            },
        };
    }
    async run() {
        let jsPaths = this.context.paths.filterByGlob('**/*.js');
        let result = new eslint_disable_task_result_1.default(this.meta, this.config);
        result.process({ esLintDisables: await getEslintDisables(jsPaths) });
        return result;
    }
}
exports.default = EslintDisableTask;
async function getEslintDisables(filePaths) {
    let fileResults = {
        errors: [],
        results: [],
    };
    await Promise.all(filePaths.map((file) => {
        return fs.promises
            .readFile(file, 'utf8')
            .then((fileString) => {
            let numMatches = 0;
            let ast = recast.parse(fileString, {
                parser: {
                    parse: babel.parse,
                },
            });
            recast.visit(ast, {
                visitComment: function (path) {
                    numMatches += (path.value.value.trim().match(ESLINT_DISABLE_REGEX) || []).length;
                    this.traverse(path);
                },
            });
            if (numMatches) {
                fileResults.results.push(...new Array(numMatches).fill({ data: file }));
            }
        })
            .catch((error) => {
            fileResults.errors.push(error);
        });
    }));
    return fileResults;
}
//# sourceMappingURL=eslint-disable-task.js.map