"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readEslintConfig = exports.EslintSummaryTask = exports.ACCEPTED_ESLINT_CONFIG_FILES = void 0;
const core_1 = require("@checkup/core");
const path_1 = require("path");
const eslint_summary_task_result_1 = require("../results/eslint-summary-task-result");
const fs_1 = require("fs");
/**
 * @export
 * @description In prioritized order as specified by https://eslint.org/docs/user-guide/configuring
 */
exports.ACCEPTED_ESLINT_CONFIG_FILES = [
    '.eslintrc.js',
    '.eslintrc.cjs',
    '.eslintrc.yaml',
    '.eslintrc.yml',
    '.eslintrc.json',
    '.eslintrc',
];
class EslintSummaryTask extends core_1.BaseTask {
    constructor(pluginName, context) {
        super(pluginName, context);
        this.meta = {
            taskName: 'eslint-summary',
            friendlyTaskName: 'Eslint Summary',
            taskClassification: {
                category: 'linting',
            },
        };
        let createEslintParser = this.context.parsers.get('eslint');
        let eslintConfig = readEslintConfig(this.context.paths, this.context.cliFlags.cwd, this.context.pkg);
        this._eslintParser = createEslintParser(eslintConfig);
        this.context.pkg;
        this.jsPaths = this.context.paths.filterByGlob('**/*.js');
    }
    async run() {
        let esLintReport = await this._runEsLint();
        this.debug('ESLint Report', esLintReport);
        let result = new eslint_summary_task_result_1.default(this.meta, this.config);
        result.process({ esLintReport });
        return result;
    }
    async _runEsLint() {
        return this._eslintParser.execute(this.jsPaths);
    }
}
exports.EslintSummaryTask = EslintSummaryTask;
function readEslintConfig(paths, basePath, pkg) {
    let eslintConfigFile = '';
    for (const acceptedConfigFile of exports.ACCEPTED_ESLINT_CONFIG_FILES) {
        let resolvedAcceptedConfigFile = path_1.join(path_1.resolve(basePath), acceptedConfigFile);
        if (paths.includes(resolvedAcceptedConfigFile)) {
            eslintConfigFile = fs_1.readFileSync(resolvedAcceptedConfigFile, { encoding: 'utf8' });
            break;
        }
    }
    if (eslintConfigFile) {
        return eslintConfigFile;
    }
    else if (pkg.eslintConfig !== null) {
        return pkg.eslintConfig;
    }
    else {
        throw new Error('No eslint config found in root (in the form of .eslintrc.* or as an eslintConfig field in package.json)');
    }
}
exports.readEslintConfig = readEslintConfig;
//# sourceMappingURL=eslint-summary-task.js.map